summaryrefslogtreecommitdiffstats
path: root/src/security/tpm/tspi.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/security/tpm/tspi.h')
-rw-r--r--src/security/tpm/tspi.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/security/tpm/tspi.h b/src/security/tpm/tspi.h
index 7157b4d7303e..aee38aa90298 100644
--- a/src/security/tpm/tspi.h
+++ b/src/security/tpm/tspi.h
@@ -4,7 +4,7 @@
#define TSPI_H_
#include <security/tpm/tss.h>
-#include <commonlib/tcpa_log_serialized.h>
+#include <commonlib/tpm_log_serialized.h>
#include <commonlib/region.h>
#include <vb2_api.h>
@@ -13,33 +13,33 @@
/**
* Get the pointer to the single instance of global
* tcpa log data, and initialize it when necessary
*/
-struct tcpa_table *tcpa_log_init(void);
+struct tpm_cb_log_table *tpm_log_init(void);
/**
* Clears the pre-RAM tcpa log data and initializes
* any content with default values
*/
-void tcpa_preram_log_clear(void);
+void tpm_preram_log_clear(void);
/**
* Add table entry for cbmem TCPA log.
* @param name Name of the hashed data
* @param pcr PCR used to extend hashed data
* @param diget_algo sets the digest algorithm
* @param digest sets the hash extended into the tpm
* @param digest_len the length of the digest
*/
-void tcpa_log_add_table_entry(const char *name, const uint32_t pcr,
- enum vb2_hash_algorithm digest_algo,
- const uint8_t *digest,
- const size_t digest_len);
+void tpm_log_add_table_entry(const char *name, const uint32_t pcr,
+ enum vb2_hash_algorithm digest_algo,
+ const uint8_t *digest,
+ const size_t digest_len);
/**
* Dump TCPA log entries on console
*/
-void tcpa_log_dump(void *unused);
+void tpm_log_dump(void *unused);
/**
* Ask vboot for a digest and extend a TPM PCR with it.
@@ -13,33 +13,33 @@
/**
* Get the pointer to the single instance of global
- * tcpa log data, and initialize it when necessary
+ * TPM log data, and initialize it when necessary
*/
@@ -13,33 +13,33 @@
/**
- * Clears the pre-RAM tcpa log data and initializes
+ * Clears the pre-RAM TPM log data and initializes
* any content with default values
*/
@@ -13,33 +13,33 @@
/**
- * Add table entry for cbmem TCPA log.
+ * Add table entry for cbmem TPM log.
* @param name Name of the hashed data
* @param pcr PCR used to extend hashed data
@@ -13,33 +13,33 @@
/**
- * Dump TCPA log entries on console
+ * Dump TPM log entries on console
*/